@@ -1,4 +1,4 @@
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2009-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -29,6 +29,10 @@ use EBox::Exceptions::Lock;
 
 use Error qw(:try);
 
+# TODO: Remove this once we change the debug behavior
+# to log only if debug = yes
+my $debug = EBox::Config::configkey('debug') eq 'yes';
+
 # Group: Public methods
 
 # Constructor: new
@@ -49,7 +53,6 @@ use Error qw(:try);
 #
 sub new
 {
-
     my ($class) = @_;
 
     my $network = EBox::Global->modInstance('network');
@@ -89,14 +92,14 @@ sub ConfigurationMethod
 #
 # Returns:
 #
-#        array ref - <EBox::Event> an info event is sent if eBox is up and
-#        running and a fatal event if eBox is down
+#        array ref - <EBox::Event> an info event is sent if Zentyal is up and
+#        running and a fatal event if Zentyal is down
 #
 sub run
 {
     my ($self) = @_;
 
-    #EBox::debug('Entering failover event...');
+    logIfDebug('Entering failover event...');
 
     $self->{eventList} = [];
     $self->{failed} = {};
@@ -107,23 +110,35 @@ sub run
     return [] unless $network->isEnabled();
 
     # We don't do anything if there are unsaved changes
-    return [] if $global->modIsChanged('network');
+    if ($global->modIsChanged('network')) {
+        EBox::warn('Failover event disabled due to unsaved changes on the Zentyal interface.');
+        return [];
+    }
 
     my $rules = $network->model('WANFailoverRules');
     my $gateways = $network->model('GatewayTable');
     $self->{gateways} = $gateways;
     $self->{marks} = $network->marksForRouters();
 
-    foreach my $id (@{$rules->enabledRows()}) {
-        #EBox::debug("Testing rules for gateway with id $id...");
+    my @enabledRules = @{$rules->enabledRows()};
+
+    # If we don't have any enabled rule we finish here
+    return [] unless @enabledRules;
+
+    foreach my $id (@enabledRules) {
+        logIfDebug("Testing rules for gateway with id $id...");
         my $row = $rules->row($id);
         $self->_testRule($row);
     }
 
     # We don't do anything if there are unsaved changes
     return [] if $global->modIsChanged('network');
+    if ($global->modIsChanged('network')) {
+        EBox::warn('Leaving failover event without doing anything due to unsaved changes on the Zentyal interface.');
+        return [];
+    }
 
-    #EBox::debug('Applying changes in the gateways table...');
+    logIfDebug('Applying changes in the gateways table...');
 
     my $needSave = 0;
     foreach my $id (@{$gateways->ids()}) {
@@ -132,9 +147,12 @@ sub run
         my $enabled = $row->valueByName('enabled');
 
         # It must be enabled if all tests are passed
-        my $enable = not($self->{failed}->{$id});
+        my $enable = $enabled;
+        if (defined($self->{failed}->{$id})) {
+            $enable = not($self->{failed}->{$id})
+        };
 
-        #EBox::debug("Properties for gateway $gwName ($id): enabled=$enabled, enable=$enable");
+        logIfDebug("Properties for gateway $gwName ($id): enabled=$enabled, enable=$enable");
 
         # We don't do anything if the previous state is the same
         if ($enable xor $enabled) {
@@ -144,7 +162,7 @@ sub run
             if ($enable) {
                 my $event = new EBox::Event(message => __x("Gateway {gw} connected", gw => $gwName),
                                     level   => 'info',
-                                    source  => $self->name());
+                                    source  => 'WAN Failover');
                 push (@{$self->{eventList}}, $event);
             }
         }
@@ -156,33 +174,37 @@ sub run
     unless ($default and $default->valueByName('enabled')) {
         # If the original default gateway is alive, restore it
         my $originalId = $network->selectedDefaultGateway();
-        #EBox::debug("The preferred default gateway is $originalId");
+        logIfDebug("The preferred default gateway is $originalId");
         my $original = $gateways->row($originalId);
         if ($original and $original->valueByName('enabled')) {
-            $default->elementByName('default')->setValue(0);
-            $default->store();
+            if ( $default ) {
+                $default->elementByName('default')->setValue(0);
+                $default->store();
+            }
             $original->elementByName('default')->setValue(1);
             $original->store();
-            #EBox::debug('The original default gateway has been restored');
+            logIfDebug('The original default gateway has been restored');
             $needSave = 1;
         } else {
-            #EBox::debug('Checking if there is another enabled gateway to set as default');
+            logIfDebug('Checking if there is another enabled gateway to set as default');
             # Check if we can find another enabled to set it as default
             my $other = $gateways->findValue('enabled' => 1);
             if ($other) {
-                $default->elementByName('default')->setValue(0);
-                $default->store();
+                if ( $default ) {
+                    $default->elementByName('default')->setValue(0);
+                    $default->store();
+                }
                 $other->elementByName('default')->setValue(1);
                 $other->store();
                 my $otherName = $other->valueByName('name');
-                #EBox::debug("The gateway $otherName is now the default");
+                logIfDebug("The gateway $otherName is now the default");
                 $needSave = 1;
             }
         }
     }
 
     if ($needSave) {
-        #EBox::debug('Regenerating rules for the gateways');
+        logIfDebug('Regenerating rules for the gateways');
         $network->regenGateways();
 
         # Workaround for squid problem
@@ -190,23 +212,23 @@ sub run
             my $squid = $global->modInstance('squid');
             my $timeout = 60;
             while ($timeout) {
-            	try {
-            		$squid->restartService();
+                try {
+                    $squid->restartService();
                     last;
                 } catch EBox::Exceptions::Lock with {
-            		sleep 5;
-            		$timeout -= 5;
-            	};
+                    sleep 5;
+                    $timeout -= 5;
+                };
             }
             if ($timeout <= 0) {
                 EBox::error('WAN Failover: proxy module has been locked for 60 seconds.');
             }
         }
     } else {
-        #EBox::debug('No need to regenerate the rules for the gateways');
+        logIfDebug('No need to regenerate the rules for the gateways');
     }
 
-    #EBox::debug('Leaving failover event...');
+    logIfDebug('Leaving failover event...');
 
     return $self->{eventList};
 }
@@ -217,7 +239,9 @@ sub _testRule # (row)
 
     my $gw = $row->valueByName('gateway');
 
-    #EBox::debug("Entering _testRule for gateway $gw...");
+    my $gwName = $self->{gateways}->row($gw)->valueByName('name');
+
+    logIfDebug("Entering _testRule for gateway $gwName...");
 
     # First test on this gateway, initialize its entry on the hash
     unless (exists $self->{failed}->{$gw}) {
@@ -227,9 +251,7 @@ sub _testRule # (row)
     # If a test for this gw has already failed we don't test any other
     return if ($self->{failed}->{$gw});
 
-    #EBox::debug("Running $typeName tests for gateway $gw...");
-
-    my $gwName = $self->{gateways}->row($gw)->valueByName('name');
+    logIfDebug("Running $typeName tests for gateway $gwName...");
 
     my $type = $row->valueByName('type');
     my $typeName = $row->printableValueByName('type');
@@ -255,11 +277,11 @@ sub _testRule # (row)
 
     for (1..$probes) {
         if ($self->_runTest($type, $host)) {
-            #EBox::debug("Probe number $_ succeded.");
+            logIfDebug("Probe number $_ succeded.");
             $successes++;
             last if ($successes >= $neededSuccesses);
         } else {
-            #EBox::debug("Probe number $_ failed.");
+            logIfDebug("Probe number $_ failed.");
             $fails++;
             last if ($fails >= $maxFails);
         }
@@ -270,7 +292,7 @@ sub _testRule # (row)
 
     my $failRatio = $fails / $probes;
 
-    if ($failRatio > $maxFailRatio) {
+    if ($failRatio >= $maxFailRatio) {
         $self->{failed}->{$gw} = 1;
 
         # Only generate event if gateway was not already disabled
@@ -284,7 +306,7 @@ sub _testRule # (row)
                                              host => $host,
                                              maxFailRatio => $maxFailRatio*100),
                                     level   => 'error',
-                                    source  => $self->name());
+                                    source  => 'WAN Failover');
         push (@{$self->{eventList}}, $event);
     }
 }
@@ -300,7 +322,7 @@ sub _runTest # (type, host)
     } elsif ($type eq 'dns') {
         $result = system("host -W 5 $host");
     } elsif ($type eq 'http') {
-        my $command = "wget $host -T 5 -O /dev/null";
+        my $command = "wget $host --tries=1 -T 5 -O /dev/null";
         $result = system($command);
     }
 
@@ -311,16 +333,36 @@ sub _setIptablesRule # (gw, set)
 {
     my ($self, $gw, $set) = @_;
 
-    # We add or delete the rule based on 'set' argument
-    my $action = $set ? '-A' : '-D';
+    my $chain = 'FAILOVER-TEST';
+    # Flush previous rules from custom chain. It'll fail silently
+    # if it doesn't exist
+    EBox::Sudo::silentRoot("/sbin/iptables -t mangle -F $chain");
+    # Remove reference to custom chain from OUTPUT. It will aslo fail
+    # silently if it doesn't exist
+    EBox::Sudo::silentRoot("/sbin/iptables -t mangle -D OUTPUT -j $chain");
 
-    my $mark = $self->{marks}->{$gw};
+    if ($set) {
+        # Create custom chain
+        EBox::Sudo::silentRoot("/sbin/iptables -t mangle -N $chain");
+        # Add refrence to custom chain from OUTPUT
+        EBox::Sudo::silentRoot("/sbin/iptables -t mangle -A OUTPUT -j $chain");
 
-    my $rule = "/sbin/iptables -t mangle $action OUTPUT "
+        # We need to add a rule to return and do nothing
+        # when the traffic is generated by ebox's apache
+        my $apachePort = EBox::Global->modInstance('apache')->port();
+        my $rule = "/sbin/iptables -t mangle -A $chain "
+             . "-p tcp --source-port $apachePort -j RETURN";
+        EBox::Sudo::root($rule);
+
+        # Add rule to mark packets generated by ebox, i.e: failover tests
+        my $mark = $self->{marks}->{$gw};
+        $rule = "/sbin/iptables -t mangle -A $chain "
              . "-m owner --gid-owner ebox -j MARK --set-mark $mark";
-
-    #EBox::debug("Setting rule: $rule\n");
-    EBox::Sudo::root($rule);
+        EBox::Sudo::root($rule);
+    } else {
+        # Delete custom chain. It'll fail silently if it doesn't exist
+        EBox::Sudo::silentRoot("/sbin/iptables -t mangle -X $chain");
+    }
 }
 
 
@@ -357,4 +399,13 @@ sub _description
     return __('Check if gateways are connected or disconnected.');
 }
 
+sub logIfDebug # (msg)
+{
+    my ($msg) = @_;
+
+    if ($debug) {
+        EBox::debug($msg);
+    }
+}
+
 1;
