@@ -1,4 +1,4 @@
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2009-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -101,7 +101,7 @@ sub _table
         new EBox::Types::Int(
            'fieldName' => 'probes',
            'printableName' => __('Number of probes'),
-           'defaultValue' => 10,
+           'defaultValue' => 6,
            'size' => 2,
            'min' => 1,
            'max' => 50,
@@ -111,7 +111,7 @@ sub _table
            'fieldName' => 'ratio',
            'printableName' => __('Required success ratio'),
            'trailingText' => '%',
-           'defaultValue' => 75,
+           'defaultValue' => 40,
            'size' => 2,
            'min' => 1,
            'max' => 100,
@@ -172,28 +172,12 @@ sub validateTypedRow
 {
     my ($self, $action, $changedFields, $allFields) = @_;
 
-    my $host = $allFields->{host}->value();
     my $type = $allFields->{type}->value();
 
-# FIXME: Temporal workaround until failover works with DHCP and PPPoE
-#    if ($type eq 'gw_ping') {
-        my $gwName = $allFields->{gateway}->value();
-        my $network = EBox::Global->modInstance('network');
-        my $gw = $network->model('GatewayTable')->row($gwName);
-        my $iface = $gw->valueByName('interface');
-
-#        if ($network->ifaceMethod($iface) eq 'ppp') {
-#            throw EBox::Exceptions::External(__('Ping to gateway not available on PPPoE interfaces, select ping to host instead'));
-#        }
-
-#        return;
-#    }
-        if ($network->ifaceMethod($iface) eq any('ppp', 'dhcp')) {
-            throw EBox::Exceptions::External(__('WAN Failover is only available for static interfaces'));
-        }
-
     return if $type eq 'gw_ping';
 
+    my $host = $allFields->{host}->value();
+
     unless (EBox::Validate::checkHost($host)) {
         throw EBox::Exceptions::External(__('Invalid value for Host'));
     }
